class CoitemController < ApplicationController

  # Make sure that the user has logged in before they can take any
  # action on checked out items
  before_filter :authorize

  def index
    list
    render :action => 'list'
  end

  # GETs should be safe (see http://www.w3.org/2001/tag/doc/whenToUseGet.html)
  verify :method => :post, :only => [ :destroy, :create, :update ],
         :redirect_to => { :action => :list }

  def list
    @coitem_pages, @coitems = paginate :coitems, :per_page => 10
  end

  def show
    @coitem = Coitem.find(params[:id])
  end

  def new
    @coitem = Coitem.new
  end

  def create
    @coitem = Coitem.new(params[:coitem])
    if @coitem.save
      flash[:notice] = 'Coitem was successfully created.'
      redirect_to :action => 'list'
    else
      render :action => 'new'
    end
  end

  def edit
    @coitem = Coitem.find(params[:id])
  end

  def update
    @coitem = Coitem.find(params[:id])
    if @coitem.update_attributes(params[:coitem])
      flash[:notice] = 'Coitem was successfully updated.'
      redirect_to :action => 'show', :id => @coitem
    else
      render :action => 'edit'
    end
  end

  def destroy
    Coitem.find(params[:id]).destroy
    redirect_to :action => 'list'
  end

  # Awesome, paginating overdue list, ordered by customer
  def overdue
    @coitem_pages, @coitems = paginate :coitems, :per_page => 50, :conditions => "due_date < DATE('NOW', 'LOCALTIME')", :order => "customer_id"
    render :action => 'list'
  end

  def return
    render :action => 'return'
  end

  def return_validate
    rentable_id = params[:rentable_id]
    @rentable = Rentable.find_by_id(rentable_id)

    if @rentable.nil?
      flash[:error] = "Unable to find this rentable"
      redirect_to :action => :return
      return
    end

    @coitem = Coitem.find_by_rentable_id(rentable_id)
    if @coitem.nil?
      flash[:error] = "This item is not checked out!"
      redirect_to :action => :return
      return
    end

    # Check if the item is overdue
    if @coitem.overdue?
      @coitem.customer.debt += @coitem.late_fee
      @coitem.customer.save
    end

    # Delete the row
    @coitem.destroy

    flash[:notice] = "Successfully returned item"
    redirect_to :action => :return
  end
end
