class GameController < ApplicationController
  layout "admin"

  # Make sure that the user has logged in before they can take any action
  before_filter :authorize

  def index
    render :action => 'index'
  end

  # GETs should be safe (see http://www.w3.org/2001/tag/doc/whenToUseGet.html)
  verify :method => :post, :only => [ :destroy, :create, :update ],
         :redirect_to => { :action => :list }

  def list
    @game_pages, @games = paginate :games, :per_page => 10
  end

  def show
    @game = Game.find(params[:id])
  end

  def new
    @game = Game.new
  end

  def create
    @game = Game.new(params[:game])
    if @game.save
      flash[:notice] = 'Game was successfully created.'
      redirect_to :action => 'list'
    else
      render :action => 'new'
    end
  end

  def edit
    @game = Game.find(params[:id])
  end

  def update
    @game = Game.find(params[:id])
    if @game.update_attributes(params[:game])
      flash[:notice] = 'Game was successfully updated.'
      redirect_to :action => 'show', :id => @game
    else
      render :action => 'edit'
    end
  end

  def destroy
    Game.find(params[:id]).destroy
    redirect_to :action => 'list'
  end

  def search
    if request.post?
      @query = params[:q]
      @games = Game.find(:all, :conditions => ["title like ?", @query[0]+"%"])
      render :action => 'searchresults'
    else
      render :action => 'search'
    end
  end
end
