class RentablePolicyController < ApplicationController

  # Make sure that a user logs in before doing any action here
  before_filter :authorize, :only => [:index, :list, :show]

  # Make sure the user is a manager before doing any action specified
  before_filter :manager, :only => [:new, :create, :edit, :update, :destroy]

  def index
    list
    render :action => 'list'
  end

  # GETs should be safe (see http://www.w3.org/2001/tag/doc/whenToUseGet.html)
  verify :method => :post, :only => [ :destroy, :create, :update ],
         :redirect_to => { :action => :list }

  def list
    @rentable_policy_pages, @rentable_policies = paginate :rentable_policies, :per_page => 10
  end

  def show
    @rentable_policy = RentablePolicy.find(params[:id])
  end

  def new
    @rentable_policy = RentablePolicy.new
  end

  def create
    @rentable_policy = RentablePolicy.new(params[:rentable_policy])
    if @rentable_policy.save
      flash[:notice] = 'RentablePolicy was successfully created.'
      redirect_to :action => 'list'
    else
      render :action => 'new'
    end
  end

  def edit
    @rentable_policy = RentablePolicy.find(params[:id])
  end

  def update
    @rentable_policy = RentablePolicy.find(params[:id])
    if @rentable_policy.update_attributes(params[:rentable_policy])
      flash[:notice] = 'RentablePolicy was successfully updated.'
      redirect_to :action => 'show', :id => @rentable_policy
    else
      render :action => 'edit'
    end
  end

  def destroy
    RentablePolicy.find(params[:id]).destroy
    redirect_to :action => 'list'
  end
end
